/*! @violentmonkey/dom@2.2.1 | ISC License */
export { Fragment, createElement, h, hm, mountDom as m, mountDom } from '@gera2ld/jsx-dom';

var _VM;
const versions = Object.assign(typeof VM !== 'undefined' && ((_VM = VM) == null ? void 0 : _VM.versions) || {}, {
  dom: '2.2.1'
});

/**
 * Return all elements that match the given `xpath` as an array.
 */
function getElementsByXPath(xpath, context = document) {
  const iterator = document.evaluate(xpath, context, null, XPathResult.ANY_TYPE, null);
  const result = [];
  let item;
  while (item = iterator.iterateNext()) {
    result.push(item);
  }
  return result;
}

/**
 * Walk a node tree and return all text contents in an array.
 */
function getTextValues(node) {
  if (node.nodeType === Node.TEXT_NODE) return [node.nodeValue];
  if (node.nodeType === Node.ELEMENT_NODE && !['script', 'style'].includes(node.tagName.toLowerCase())) {
    return Array.from(node.childNodes).flatMap(getTextValues);
  }
  return [];
}

/**
 * Observe an existing `node` until `callback` returns `true`.
 * The returned function can be called explicitly to disconnect the observer.
 *
 * ```js
 * VM.observe(document.body, () => {
 *   const node = document.querySelector('.profile');
 *   if (node) {
 *     console.log('It\'s there!');
 *     return true;
 *   }
 * });
 * ```
 */
function observe(node, callback, options) {
  const observer = new MutationObserver((mutations, ob) => {
    const result = callback(mutations, ob);
    if (result) disconnect();
  });
  observer.observe(node, Object.assign({
    childList: true,
    subtree: true
  }, options));
  const disconnect = () => observer.disconnect();
  return disconnect;
}

export { getElementsByXPath, getTextValues, observe, versions };
